
import numpy
import sys
import random

DEFAULT_SIZE = (20,20)

import logging
logger = logging.getLogger('game')

class ConwaysGame:
    def __init__(self, shape=DEFAULT_SIZE, data=None):
        """
        Inicializuje matici bunek.

        Pokud  `data` neni None, uvodni stav je inicializovat z nich.
        Jinak se vygeneruje prazdna matice o velikost `shape`
        """
        if data is None:
            self._data = numpy.zeros(shape=shape, dtype=bool)
        else:
            assert len(data.shape) == 2, data.shape
            self._data = data

    def add_random_cells(self, count=None):
        """Ozivi nahodne `count` bunek.   
        Pokud je `count` == 0, ozivi 5% bunek
        """
        _d = self._data
        if count is None:
            count = 5 * _d.shape[0] * _d.shape[1] // 100

        for i in range(count):
            cell_address = []
            for axe,axe_size in enumerate(_d.shape):
                axe_position = random.randint(0,axe_size-1)
                cell_address.append(axe_position)

            cell_address = tuple(cell_address)
            _d[cell_address] = True
                

    def dump(self, fileobj=sys.stdout):
        """
        Vypise hru do `fileobj`
        """
        _d = self._data
        for x in range(_d.shape[0]):
            for y in range(_d.shape[0]):
                if _d[x][y]:
                    fileobj.write('# ')
                else: 
                    fileobj.write('. ')
                fileobj.write('\n')
